smartcard.pyro.server.RemoteCardConnection.RemoteCardConnection

# ``smartcard`.`pyro`.`server`.`RemoteCardConnection`.`RemoteCardConnection``

class documentation

`class RemoteCardConnection(CardConnectionDecorator, Pyro.core.ObjBase):`

View In Hierarchy

Remote connection class. Handles connection with a card inserted inside a remote PC.

Method | `__init__` | Construct a new remote card connection.

Inherited from `CardConnectionDecorator`:

Method | `addObserver` | call inner component addObserver
Method | `addSWExceptionToFilter` | call inner component addSWExceptionToFilter
Method | `connect` | call inner component connect
Method | `control` | call inner component control
Method | `deleteObserver` | call inner component deleteObserver
Method | `disconnect` | call inner component disconnect
Method | `getATR` | call inner component getATR
Method | `getAttrib` | call inner component getAttrib
Method | `getProtocol` | call inner component getProtocol
Method | `getReader` | call inner component getReader
Method | `reconnect` | call inner component reconnect
Method | `setErrorCheckingChain` | call inner component setErrorCheckingChain
Method | `setProtocol` | call inner component setProtocol
Method | `transmit` | call inner component transmit
Instance Variable | `component` | Undocumented

Inherited from `CardConnection` (via `CardConnectionDecorator`):

Method | `__del__` | Connect to card.
Method | `__enter__` | Enter the runtime context.
Method | `__exit__` | Exit the runtime context trying to disconnect.
Method | `doControl` | Performs the command control.
Method | `doGetAttrib` | Performs the command get attrib.
Method | `doTransmit` | Performs the command APDU transmission.
Class Variable | `RAW_protocol` | Undocumented
Class Variable | `T0_protocol` | Undocumented
Class Variable | `T15_protocol` | Undocumented
Class Variable | `T1_protocol` | Undocumented
Instance Variable | `defaultprotocol` | Undocumented
Instance Variable | `errorcheckingchain` | Undocumented
Instance Variable | `reader` | Undocumented

Inherited from `Observable` (via `CardConnectionDecorator`, `CardConnection`):

Method | `clearChanged` | Undocumented
Method | `countObservers` | Undocumented
Method | `deleteObservers` | Undocumented
Method | `hasChanged` | Undocumented
Method | `notifyObservers` | If 'changed' indicates that this object has changed, notify all its observers, then call clearChanged(). Each observer has its update() called with two arguments: this observable object and the generic 'arg'.
Method | `setChanged` | Undocumented
Instance Variable | `changed` | Undocumented
Instance Variable | `obs` | Undocumented

Inherited from `Synchronization` (via `CardConnectionDecorator`, `CardConnection`, `Observable`):

Instance Variable | `mutex` | Undocumented

def __init__(self, cardConnectionComponent):
overrides `smartcard.CardConnectionDecorator.CardConnectionDecorator.__init__`

Construct a new remote card connection.

connection: the reader connection